<?php

namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use HCM\Util\HCMParameters;
use Geral\Util\DateUtil;

class DashboardController extends TeknisaCrud {

    protected $dataSourceGetTarefas                      = 'filacontato_getIndicadorTarefas';
    protected $dataSourceGetTarefasChamado               = 'filacontato_getIndicadorTarefasChamado';
    protected $dataSourceGetCompromissos                 = 'planocupacao_getIndicadorCompromissos';
    protected $dataSourceGetOportunidades                = 'crm_oportuni_getIndicadorOportunidades';
    protected $dataSourceGetFasesOportunidadesAbertas    = 'crm_fasenegoci_getIndicadorFasesOportunidadesAbertas';
    protected $dataSourceGetFasesOportunidadesFechadas   = 'crm_fasenegoci_getIndicadorFasesOportunidadesFechadas';
    protected $dataSourceGetLeads                        = 'crm_candidato_getIndicadorLeads';
    protected $dataSourceGetLeadsPorOperador             = 'crm_candidato_getIndicadorLeadsPorOperador';
    protected $dataSourceGetValorOportunidadeFechada     = 'crm_oportuni_getIndicadorValorOportunidadeFechada';
    protected $dataSourceGetValorOportunidadeAberta      = 'crm_oportuni_getIndicadorValorOportunidadeAberta';
    protected $dataSourceGetValorOportunidadePerdida     = 'crm_oportuni_getIndicadorValorOportunidadePerdida';
    protected $dataSourceGetChamados                     = 'contato_getIndicadorChamados';
    protected $dataSourceGetFunilOportunidades           = 'evolcont_getIndicadorFunilOportunidades';
    protected $dataSourceGetTermometroOportunidades      = 'crm_oportuni_getIndicadorTermometroOportunidades';
    protected $dataSourceGetTermometroPorOperador        = 'crm_oportuni_getIndicadorTermometroPorOperador';
    protected $dataSourceGetMetaValor                    = 'crm_metas_getIndicadorMetaValor';
    protected $dataSourceGetMetaValorPorOperador         = 'crm_metas_getIndicadorMetaValorPorOperador';
    protected $dataSourceGetMetaConversao                = 'crm_metas_getIndicadorMetaConversao';
    protected $dataSourceGetMetaConversaoPorOperador     = 'crm_metas_getIndicadorMetaConversaoPorOperador';
    protected $dataSourceGetTicketsAbertosFechados       = 'crm_getTikets_AbertosFechados';
    protected $dataSourceGetConsolidadoTicketPorStatus   = 'crm_consolidado_ticket_status';
   
    protected $parameterBagColumns = array();
    protected $dashboardService;
    protected $util;

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, $dashboardService, $util){
        $this->dataSourceManager = $dataSourceManager;
        $this->parameterBag = $parameterBag;
        $this->dashboardService = $dashboardService;
        $this->util = $util;
        parent::__construct($dataSourceManager, $parameterBag);
    }

        
    public function getChamados (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('CDOPERADOR');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetChamados);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getFunilOportunidades (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERADORES', 'CRM_NRORGTRAB');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetFunilOportunidades);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getMetaValor (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_CDOPERSHIERARQINF', 'P_NRORG');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetMetaValor);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getMetaValorPorOperador (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_CDOPERSHIERARQINF', 'P_NRORG', 'ORDEM');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetMetaValorPorOperador);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getMetaConversao (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_CDOPERSHIERARQINF', 'P_NRORG');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetMetaConversao);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getMetaConversaoPorOperador (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_CDOPERSHIERARQINF', 'P_NRORG', 'ORDEM');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetMetaConversaoPorOperador);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getTarefas (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $filterData = $request->getFilterCriteria();
            if(count($filterData->getConditions()) > 1){
                $this->parameterBagColumns = array('STATUS', 'CDOPERADOR', 'TIPO');
                $filterData->setDataSourceName($this->dataSourceGetTarefasChamado);
            }else {
                $this->parameterBagColumns = array('STATUS', 'CDOPERADOR');
                $filterData->setDataSourceName($this->dataSourceGetTarefas);
            }
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData);
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getCompromissos (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('STATUS', 'CDOPERADOR');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetCompromissos);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getOportunidades (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('STATUS', 'CDOPERADOR', 'CRM_NRORGTRAB', 'NRORG');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetOportunidades);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    public function getOccurrences (Request\Row $request, Response $response) {
        
        $row = $request->getRow();
       
        try{

            $rows = $this->dashboardService->getOccurrences($row);
            
            $returnArray = array(
            "NRORDER"        => $rows["NRORDER"],
            "QUANTIDADE"     => $rows["QUANTIDADE"],
            "STATUS"    	 => $rows["STATUS"]
            );
            
            $response->addDataSet(new DataSet("DADOS", array($returnArray)));

        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getFasesOportunidadesFechadas (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERADORES');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetFasesOportunidadesFechadas);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getFasesOportunidadesAbertas (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERADORES');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetFasesOportunidadesAbertas);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getValorOportunidadeAberta (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERADORES');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetValorOportunidadeAberta);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getValorOportunidadeFechada (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERADORES');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetValorOportunidadeFechada);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getValorOportunidadePerdida (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERADORES');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetValorOportunidadePerdida);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getLeads (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERADORES');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetLeads);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getTermometroOportunidades (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERADORES', 'CRM_NRORGTRAB');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetTermometroOportunidades);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getTermometroPorOperador (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_NRPARCOPERSHIERARQINF', 'P_COLORS', 'P_CRM_NRORGTRAB');
            $filterData = $request->getFilterCriteria();
            $newFilterData = $this->populateParameterBag($filterData);
            $conditions = $filterData->getConditions();
            $params = array();
            
            foreach ($conditions as $key => $value) {
                $params[$value['columnName']] = $value['value'];
            }
            
            $params["P_COLORS"] = "'".implode("','", $params["P_COLORS"])."'";
            $params["P_NRPARCOPERSHIERARQINF"] = implode(",", $params["P_NRPARCOPERSHIERARQINF"]);
            
            $return = $this->dashboardService->getPivotedTermometro($params); 
            
            $response->addDataSet(new DataSet('termPorOperador', $return));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getRelatorioLeadsPorOperador (DTO\Request\Filter $request, DTO\Response $response) {
        $intervalo = $this->util->findFilterValue($request, 'INTERVALO');
        $operadores = $this->util->findFilterValue($request, 'CDOPERADOR');
        
        $dateFilters = array(
            array(
                "columnName"    => 'DATAINICIAL',
                "operator"      => '=',
                "value"         => isset($intervalo[0]) ? $intervalo[0] : null
            ),
            array(
                "columnName"    => 'DATAFINAL',
                "operator"      => '=',
                "value"         => isset($intervalo[1]) ? $intervalo[1] : null
            ),
            array(
                "columnName"    => 'P_CDOPERADORES',
                "operator"      => '=',
                "value"         => $operadores
            ),
        );
        
        $request = $this->util->removeRequestFilters($request, ['INTERVALO', 'DATAFINAL', 'CDOPERADOR']);
        $request = $this->util->addRequestFilters($request, $dateFilters);

        $this->getLeadsPorOperador($request, $response);
    }
    
    public function getLeadsPorOperador (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $cdOperFilter = $this->util->findFilter($request, 'P_CDOPERADORES');
            $cdOperString = $this->util->stringfyArray($cdOperFilter['value']);
            
            $cdOperFilter['value'] = $cdOperString;
            $request = $this->util->editRequestFilters($request, 'P_CDOPERADORES', $cdOperFilter);
            
            $this->parameterBagColumns = array('P_CDOPERADORES', 'P_NRORG', 'DATAINICIAL', 'DATAFINAL', 'P_CRM_NRORGTRAB');
            
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetLeadsPorOperador);
            
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData);
            
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {
        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );


        return $newFilterCriteria;
    }
    
    public function getTicketAbertoFechado (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_CDOPERSHIERARQINF');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetTicketsAbertosFechados);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
            
    public function getTicketrStatus (DTO\Request\Filter $request, DTO\Response $response) {
        try{
            $this->parameterBagColumns = array('P_NRORG', 'P_CDOPERSHIERARQINF');
            $filterData = $request->getFilterCriteria();
            $filterData->setDataSourceName($this->dataSourceGetConsolidadoTicketPorStatus);
            $newFilterData = $this->populateParameterBag($filterData);
            $dataSet = $this->dataSourceManager->findBy($newFilterData); 
            $response->addDataSet($dataSet);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}