<?php
namespace Teknisa\CRM\Factory;

use Doctrine\ORM\EntityManager;

class ReplicacaoParceiroFactory {
    const NOT_FOUND = 'NOT_FOUND';
    protected $entityManager;
    /** @var Environment */
    protected $environment;
    
    public function __construct(EntityManager $entityManager, $environment) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->connection = $entityManager->getConnection();
    }

    public function replicaLead($nrparcnegocio, $dados){
        try{
           $lead = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\CrmCandidato')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );
            
            $this->preparaDados($dados);
            if(is_object($lead)){
                //Só updata o que foi encontrado no registro atualizado
                $lead->setNmcandidato($dados['RAZAO']     === self::NOT_FOUND || empty($dados['RAZAO']) ? $lead->getNmcandidato()  : $dados['RAZAO']);
                $lead->setNmfantcan($dados['FANTASIA']    === self::NOT_FOUND || empty($dados['FANTASIA']) ? $lead->getNmfantcan()    : $dados['FANTASIA']);
                $lead->setNrinsjurcan($dados['INSCRICAO'] === self::NOT_FOUND || empty($dados['INSCRICAO']) ? $lead->getNrinsjurcan()  : $dados['INSCRICAO']);
                $lead->setIdtpijurcan($dados['TIPOINSCR'] === self::NOT_FOUND || empty($dados['TIPOINSCR']) ? $lead->getIdtpijurcan()  : $dados['TIPOINSCR']);
                $lead->setCdsegmer($dados['SEGMENTO']     === self::NOT_FOUND || empty($dados['SEGMENTO']) ? $lead->getCdsegmer()     : $dados['SEGMENTO']);
                $lead->setIdstatuscan(!empty($lead->getIdstatuscan()) ? $lead->getIdstatuscan()  : $dados['STATUS']);
                $lead->setNrfunccan($dados['N_FUNC']      === self::NOT_FOUND || empty($dados['N_FUNC']) ? $lead->getNrfunccan()    : $dados['N_FUNC']);
                $lead->setCdmododivulg($dados['MDDIVULG'] === self::NOT_FOUND || empty($dados['MDDIVULG']) ? $lead->getCdmododivulg() : $dados['MDDIVULG']);
                $lead->setIdativo($dados['IDATIVO']       === self::NOT_FOUND || empty($dados['IDATIVO']) ? $lead->getIdativo() : $dados['IDATIVO']);
                if(isset($dados['PARCOPERADOR'])) {
                    $lead->setNrparcpropri($dados['PARCOPERADOR'] === self::NOT_FOUND ? $lead->getNrparcpropri() : $dados['PARCOPERADOR']);
                } else {
                    $lead->setNrparcpropri($dados['OPERADOR'] === self::NOT_FOUND ? $lead->getNrparcpropri() : $dados['OPERADOR']);
                }
                $this->entityManager->persist($lead);
                $this->entityManager->flush();
            }else{
                throw new \Exception('Lead não encontrado.');      
            }
        }catch(\Exception $e){
            throw new \Exception($e->getMessage());
        }
    }
    
    public function replicaParceiro($nrparcnegocio, $dados){    
        try{
            $parceiro = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Parcnegocio')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );
            //Os Responsáveis vindos do prospect/lead vem como NRPARCNEGOCIO
            //Pega o CDOPERADOR do responsável
            if(!empty($dados['OPERADOR'])){
                $operador = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Operador')->findOneBy(
                    array(
                        'nrparcnegocio' => $dados['OPERADOR'],
                        'nrorg' => $this->environment->getNrOrgTrab()
                    )
                );
                
                if(is_object($operador)){
                    $dados['OPERADOR'] = $operador->getCdoperador();
                }
            } else if(!empty($dados['CDOPERADOR'])) {
                $dados['OPERADOR'] = $dados['CDOPERADOR'];
            }
            
            if(!empty($dados['TIPOINSCR'])){
                switch($dados['TIPOINSCR']){
                    case 'J':
                        $dados['TIPOINSCR'] = 'CNPJ';
                    break;
                    case 'F':
                        $dados['TIPOINSCR'] = 'CPF';
                    break;
                    case 'I':
                        $dados['TIPOINSCR'] = 'LIVRE';
                    break;
                    case 'O':
                        $dados['TIPOINSCR'] = 'CODIGO';
                    break;
                }
            }
            
            
            
            if(is_object($parceiro)){
                //Só updata o que não for vazio no array de dados
                $parceiro->setNmprincipalparc($dados['RAZAO']     === self::NOT_FOUND || empty($dados['RAZAO']) ? $parceiro->getNmprincipalparc()   : $dados['RAZAO']);
                $parceiro->setNmsecundariparc($dados['FANTASIA']  === self::NOT_FOUND || empty($dados['FANTASIA']) ? $parceiro->getNmsecundariparc()   : $dados['FANTASIA']);
                $parceiro->setNrinscricaoparc($dados['INSCRICAO'] === self::NOT_FOUND ? $parceiro->getNrinscricaoparc()   : $dados['INSCRICAO']);
                $parceiro->setCdtipoinscricao($dados['TIPOINSCR'] === self::NOT_FOUND || empty($dados['TIPOINSCR']) ? $parceiro->getCdtipoinscricao()   : $dados['TIPOINSCR']);
                $parceiro->setCdsegmer($dados['SEGMENTO']         === self::NOT_FOUND ? $parceiro->getCdsegmer()          : $dados['SEGMENTO']);
                $parceiro->setCdativcli($dados['RAMOATIV']        === self::NOT_FOUND ? $parceiro->getCdativcli()         : $dados['RAMOATIV']);
                $parceiro->setNrseqtpativcli($dados['TIPOATIV']   === self::NOT_FOUND ? $parceiro->getNrseqtpativcli()    : $dados['TIPOATIV']);
                $parceiro->setIdativo($dados['IDATIVO']           === self::NOT_FOUND ? $parceiro->getIdativo()    : $dados['IDATIVO']);
                if(!empty($dados['CDOPERADOR'])) {
                    $parceiro->setCdoperresponsavel($dados['CDOPERADOR'] === self::NOT_FOUND ? $parceiro->getCdoperresponsavel() : $dados['CDOPERADOR']);
                } else {
                    $parceiro->setCdoperresponsavel($dados['OPERADOR'] === self::NOT_FOUND ? $parceiro->getCdoperresponsavel() : $dados['OPERADOR']);
                }
                $this->entityManager->persist($parceiro);
                $this->entityManager->flush();
            }else{
                throw new \Exception('Parceiro não encontrado.');    
            }
        }catch(\Exception $e){
            throw new \Exception($e->getMessage());
        }
    }
    
    public function replicaProspect($nrparcnegocio, $dados){
        try{
            $prospect = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\Prospect')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );  
            $this->preparaDados($dados);
            if(is_object($prospect)){
                //Só updata o que não for vazio no array de dados
                $prospect->setNmrazsocpros($dados['RAZAO']      === self::NOT_FOUND || empty($dados['RAZAO']) ? $prospect->getNmrazsocpros() : $dados['RAZAO']);
                $prospect->setNmfantpros($dados['FANTASIA']     === self::NOT_FOUND || empty($dados['FANTASIA']) ? $prospect->getNmfantpros() : $dados['FANTASIA']);
                $prospect->setNrinsjurpros($dados['INSCRICAO']  === self::NOT_FOUND ? $prospect->getNrinsjurpros() : $dados['INSCRICAO']);
                $prospect->setIdtpijurpros($dados['TIPOINSCR']  === self::NOT_FOUND || empty($dados['TIPOINSCR']) ? $prospect->getIdtpijurpros() : $dados['TIPOINSCR']);
                $prospect->setCdsegmer($dados['SEGMENTO']       === self::NOT_FOUND ? $prospect->getCdsegmer() : $dados['SEGMENTO']);
                $prospect->setIdqualificado($dados['STATUS']    === self::NOT_FOUND || empty($dados['STATUS']) ? $prospect->getIdqualificado() : $dados['STATUS']);
                $prospect->setNrfuncpros($dados['N_FUNC']       === self::NOT_FOUND ? $prospect->getNrfuncpros() : $dados['N_FUNC']);
                $prospect->setCdmododivulg($dados['MDDIVULG']   === self::NOT_FOUND ? $prospect->getCdmododivulg() : $dados['MDDIVULG']);
                $prospect->setCdativcli($dados['RAMOATIV']      === self::NOT_FOUND ? $prospect->getCdativcli() : $dados['RAMOATIV']);
                $prospect->setNrseqtpativcli($dados['TIPOATIV'] === self::NOT_FOUND ? $prospect->getNrseqtpativcli() : $dados['TIPOATIV']);
                $prospect->setIdativo($dados['IDATIVO']         === self::NOT_FOUND ? $prospect->getIdativo() : $dados['IDATIVO']);
                if(isset($dados['PARCOPERADOR'])) {
                    $prospect->setNrparcresprosp($dados['PARCOPERADOR'] === self::NOT_FOUND ? $prospect->getNrparcresprosp() : $dados['PARCOPERADOR']);
                } else {
                    $prospect->setNrparcresprosp($dados['OPERADOR'] === self::NOT_FOUND ? $prospect->getNrparcresprosp() : $dados['OPERADOR']);
                }
                
                $this->entityManager->persist($prospect);
                $this->entityManager->flush();
            }else{
                throw new \Exception('Prospect não encontrado.');      
            }
        }catch(\Exception $e){
            throw new \Exception($e->getMessage());
        }
    }
    
    public function replicaCliente($nrparcnegocio, $dados){
        try{
            $cliente = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Cliente')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );  
            $parceiro = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Parcnegocio')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );  
            $this->preparaDados($dados);
            if(is_object($cliente)){
                //Só updata o que não for vazio no array de dados
                $cliente->setNmrazsocclie($dados['RAZAO']      === self::NOT_FOUND || empty($dados['RAZAO']) ? $cliente->getNmrazsocclie() : $dados['RAZAO']);
                $cliente->setNmfantclie($dados['FANTASIA']     === self::NOT_FOUND || empty($dados['FANTASIA']) ? $cliente->getNmmaeclie() : $dados['FANTASIA']);
                $cliente->setNrinsjurclie($dados['INSCRICAO']  === self::NOT_FOUND ? $cliente->getNrinsjurclie() : $dados['INSCRICAO']);
                $cliente->setIdtpijurclie($dados['TIPOINSCR']  === self::NOT_FOUND || empty($dados['TIPOINSCR']) ? $cliente->getIdtpijurclie() : $dados['TIPOINSCR']);
                $cliente->setCdsegmer($dados['SEGMENTO']       === self::NOT_FOUND ? $cliente->getCdsegmer() : $dados['SEGMENTO']);
                $cliente->setNrfuncclie($dados['N_FUNC']       === self::NOT_FOUND ? $cliente->getNrfuncclie() : $dados['N_FUNC']);
                $cliente->setCdmododivulg($dados['MDDIVULG']   === self::NOT_FOUND ? $cliente->getCdmododivulg() : $dados['MDDIVULG']);
                $cliente->setCdativcli($dados['RAMOATIV']      === self::NOT_FOUND ? $cliente->getCdativcli() : $dados['RAMOATIV']);
                $cliente->setIdativo($dados['IDATIVO']         === self::NOT_FOUND ? $cliente->getIdativo() : $dados['IDATIVO']);
                $parceiro->setNrseqtpativcli($dados['TIPOATIV'] === self::NOT_FOUND ? $parceiro->getNrseqtpativcli() : $dados['TIPOATIV']);
                if(isset($dados['PARCOPERADOR'])) {
                    $parceiro->setCdoperresponsavel($dados['PARCOPERADOR'] === self::NOT_FOUND ? $parceiro->getCdoperresponsavel() : $dados['PARCOPERADOR']);
                } else {
                    $parceiro->setCdoperresponsavel($dados['OPERADOR'] === self::NOT_FOUND ? $parceiro->getCdoperresponsavel() : $dados['OPERADOR']);
                }
                
                $this->entityManager->persist($cliente);
                $this->entityManager->flush();
            }else{
                throw new \Exception('Cliente não encontrado.');      
            }
        }catch(\Exception $e){
            throw new \Exception($e->getMessage());
        }
    }
    
    public function getDadosLead(&$dados, $nrparcnegocio){
        try{
           $lead = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\CrmCandidato')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );
            
            if(is_object($lead)){
                $dados['RAZAO']      = $lead->getNmcandidato();
                $dados['FANTASIA']   = $lead->getNmfantcan();
                $dados['INSCRICAO']  = $lead->getNrinsjurcan();
                $dados['TIPOINSCR']  = $lead->getIdtpijurcan();
                $dados['SEGMENTO']   = $lead->getCdsegmer();
                $dados['STATUS']     = $lead->getIdstatuscan();
                $dados['OPERADOR']   = $lead->getNrparcpropri();
                $dados['N_FUNC']     = $lead->getNrfunccan();
                $dados['MDDIVULG']   = $lead->getCdmododivulg();
                $dados['RAMOATIV']   = self::NOT_FOUND;
                $dados['TIPOATIV']   = self::NOT_FOUND;
                $dados['IDATIVO']    = $lead->getIdativo();
            }
        }catch(\Exception $e){
            throw new \Exception('Lead: '.$e->getMessage());   
        }
    }
    
    public function getDadosParceiro(&$dados, $nrparcnegocio){    
        try{
            $parceiro = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Parcnegocio')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );
            
            if(is_object($parceiro)){
                $dados['RAZAO']      = $parceiro->getNmprincipalparc();
                $dados['FANTASIA']   = $parceiro->getNmsecundariparc();
                $dados['INSCRICAO']  = $parceiro->getNrinscricaoparc();
                $dados['TIPOINSCR']  = $parceiro->getCdtipoinscricao();
                $dados['SEGMENTO']   = $parceiro->getCdsegmer();
                $dados['STATUS']     = self::NOT_FOUND;
                $dados['OPERADOR']   = $parceiro->getCdoperresponsavel();
                $dados['N_FUNC']     = self::NOT_FOUND;
                $dados['MDDIVULG']   = self::NOT_FOUND;
                $dados['RAMOATIV']   = $parceiro->getCdativcli();
                $dados['TIPOATIV']   = $parceiro->getNrseqtpativcli();
                $dados['IDATIVO']    = $parceiro->getIdativo();
            }
        }catch(\Exception $e){
            throw new \Exception('Parceiro: '.$e->getMessage());   
        }
    }
    
    public function getDadosProspect(&$dados, $nrparcnegocio){
        try{
            $prospect = $this->entityManager->getRepository('\Teknisa\Model\Crm\Entities\Prospect')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            ); 
            
            if(is_object($prospect)){
                $dados['RAZAO']      = $prospect->getNmrazsocpros();
                $dados['FANTASIA']   = $prospect->getNmfantpros();
                $dados['INSCRICAO']  = $prospect->getNrinsjurpros();
                $dados['TIPOINSCR']  = $prospect->getIdtpijurpros();
                $dados['SEGMENTO']   = $prospect->getCdsegmer();
                $dados['STATUS']     = $prospect->getIdqualificado();
                $dados['OPERADOR']   = $prospect->getNrparcresprosp();
                $dados['N_FUNC']     = $prospect->getNrfuncpros();
                $dados['MDDIVULG']   = $prospect->getCdmododivulg();
                $dados['RAMOATIV']   = $prospect->getCdativcli();
                $dados['TIPOATIV']   = $prospect->getNrseqtpativcli();
                $dados['IDATIVO']    = $prospect->getIdativo();
            }
        }catch(\Exception $e){
            throw new \Exception('Prospect: '.$e->getMessage());   
        }
    }
    
    public function getDadosCliente(&$dados, $nrparcnegocio){
        try{
            $cliente = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Cliente')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            ); 
            $parceiro = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Parcnegocio')->findOneBy(
                array(
                    'nrparcnegocio' => $nrparcnegocio,
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            ); 
            if(is_object($cliente)){
                $operador = $this->getOperador($parceiro->getCdOperResponsavel(), null);
                if(!empty($operador)) {
                    $dados['CDOPERADOR'] = $operador['CDOPERADOR'];
                    $dados['PARCOPERADOR'] = $operador['NRPARCNEGOCIO'];
                } else {
                    $dados['CDOPERADOR'] = $operador;
                    $dados['PARCOPERADOR'] = $operador;
                }
                $dados['RAZAO']      = $cliente->getNmrazsocclie();
                $dados['FANTASIA']   = $cliente->getNmfantclie();
                $dados['INSCRICAO']  = $cliente->getNrinsjurclie();
                $dados['TIPOINSCR']  = $cliente->getIdtpijurclie();
                $dados['SEGMENTO']   = $cliente->getCdsegmer();
                $dados['N_FUNC']     = $cliente->getNrfuncclie();
                $dados['MDDIVULG']   = $cliente->getCdmododivulg();
                $dados['RAMOATIV']   = $cliente->getCdativcli();
                $dados['TIPOATIV']   = $parceiro->getNrseqtpativcli();
                $dados['IDATIVO']    = $cliente->getIdativo();
            }
        }catch(\Exception $e){
            throw new \Exception('Cliente: '.$e->getMessage());   
        }
    }
    
    private function preparaDados(&$dados){
        //Os Responsáveis vindos do parceiro vem como CDOPERADOR
        //Pega o NRPARCNEGOCIO do responsável
        if(!empty($dados['OPERADOR']) && !is_integer($dados['OPERADOR']) && strlen($dados['OPERADOR']) === 12){
            $operador = $this->entityManager->getRepository('\Teknisa\Model\Geral\Entities\Operador')->findOneBy(
                array(
                    'cdoperador' => $dados['OPERADOR'],
                    'nrorg' => $this->environment->getNrOrgTrab()
                )
            );   
            if(is_object($operador)){
                $dados['OPERADOR'] = $operador->getNrparcnegocio();
            }
        }
        if(!empty($dados['TIPOINSCR'])){
            switch($dados['TIPOINSCR']){
                case 'CNPJ':
                    $dados['TIPOINSCR'] = 'J';
                break;
                case 'CPF':
                    $dados['TIPOINSCR'] = 'F';
                break;
                case 'LIVRE':
                    $dados['TIPOINSCR'] = 'I';
                break;
                case 'CODIGO':
                    $dados['TIPOINSCR'] = 'O';
                break;
            }
        }
    }
    
    public function getOperador($cdoperador, $nrparcnegocio) {
        $sql = "SELECT CDOPERADOR, NRPARCNEGOCIO FROM OPERADOR WHERE (NRPARCNEGOCIO = :NRPARCNEGOCIO OR CDOPERADOR = :CDOPERADOR)";
        
        $params = array(
            'CDOPERADOR'    => $cdoperador,
            'NRPARCNEGOCIO' => $nrparcnegocio
        );
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $return = $std->fetchAll();
        if(!empty($return)) {
            return $return[0];
        } else {
            return array(
                'CDOPERADOR' => 'NOT_FOUND',
                'NRPARCNEGOCIO' => 'NOT_FOUND'
            );
        }
    }
}