/*
NOME: 0007_DENSTPO_EXPORTA_NF_ENTRADA.SQL

DESCRIO: Procedimento para gerao das NFs de entrada em tabela.

CRIAO: 19/08/2008 - Fabrcio Marcelo da Silva

@C:\Web_505\Xdb\Src\Cli\DEN\Sql\0007_DENSTPO_EXPORTA_NF_ENTRADA.SQL

RAISE_APPLICATION_ERROR(-20501, '' , TRUE);
*/

CREATE OR REPLACE PROCEDURE EXPORTA_NF_ENTRADA(
     P_DTINICIAL IN NOTAFISCAL.DTENTRSAID%TYPE,
     P_DTFINAL   IN NOTAFISCAL.DTENTRSAID%TYPE)
AS
   V_DTGRV         DATE;
   V_HRGRV         VARCHAR2(04);

   /* Variveis referente ao corpo da nota fiscal */
   V_BASEICMS      NUMBER;
   V_VALRICMS      NUMBER;
   V_BASEIPI       NUMBER;
   V_VALRIPI       NUMBER;
   V_BASEICMRET    NUMBER;
   V_VALRICMRET    NUMBER;
   V_VALRIRRF      NUMBER;
   V_VALRINSS      NUMBER;
   V_VALRISS       NUMBER;
   V_VALRPIS       NUMBER;
   V_VALRCOFINS    NUMBER;
   V_VALRCSLL      NUMBER;
   V_BASEPISST     NUMBER;
   V_VALRPISST     NUMBER;
   V_BASECOFINSST  NUMBER;
   V_VALRCOFINSST  NUMBER;

   /* Variveis referente aos itens da nota fiscal */
   V_VALRICMSIT    NUMBER;
   V_ALIQICMSIT    NUMBER;
   V_BASEICMSIT    NUMBER;
   V_VALRIPIIT     NUMBER;
   V_ALIQIPIIT     NUMBER;
   V_BASEIPIIT     NUMBER;
   V_VALRIRRFIT    NUMBER;
   V_ALIQIRRFIT    NUMBER;
   V_BASEIRRFIT    NUMBER;
   V_VALRISSIT     NUMBER;
   V_ALIQISSIT     NUMBER;
   V_BASEISSIT     NUMBER;
   V_VALRINSSIT    NUMBER;
   V_ALIQINSSIT    NUMBER;
   V_BASEINSSIT    NUMBER;
   V_BASEICMRETIT  NUMBER;
   V_VALRICMRETIT  NUMBER;
   V_BASEPISSTIT   NUMBER;
   V_VALRPISSTIT   NUMBER;
   V_ALIQPISSTIT   NUMBER;
   V_BASECOFSTIT   NUMBER;
   V_VALRCOFSTIT   NUMBER;
   V_ALIQCOFSTIT   NUMBER;
BEGIN
   V_DTGRV := NULL;
   V_HRGRV := NULL;

   /* Retorna data e hora de exportao */
   BEGIN
      SELECT TO_DATE(SYSDATE), TO_CHAR(SYSDATE,'HH24MI')
      INTO V_DTGRV, V_HRGRV
      FROM DUAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_DTGRV := NULL;
         V_HRGRV := NULL;
   END;
   /* Verificao dos documentos de Entrada */
   FOR C_ENTRADA IN (SELECT N.CDFILIAL,
                            N.NRLANCTONF,
                            N.CDFILIRECE,
                            SUBSTR(F.CDGRUPFILI,7,2) AS EMPRESA,
                            SUBSTR(F.CDGRUPFILI,9,2) AS FILIAL,
                            LPAD(N.NRNOTAFISC,6) AS NRNOTAFISC,
                            SUBSTR(N.CDSERIEENTR,1,3) AS CDSERIEENTR,
                            TO_CHAR(N.DTEMISSAO, 'DDMMYYYY') AS DTEMISSAO,
                            FO.NRINSJURFORN,
                            FO.CDFORMPGTO,
                            N.VRPRODUTOS,
                            N.VRNOTAFISC,
                            '01' AS LOJA,
                            N.CDTIPOOPER
                       FROM NOTAFISCAL N, FORNECEDOR FO,
                            (SELECT CDFILIAL, MIN(CDGRUPFILI) AS CDGRUPFILI
                               FROM FILGRUPFILI
                              GROUP BY CDFILIAL) F
                      WHERE (N.IDENTRSAIDOP = 'E')
                        AND (N.DTENTRSAID BETWEEN P_DTINICIAL AND P_DTFINAL)
                        AND (N.CDTIPOOPER IN  ('01','03','11'))
                        AND (N.IDSTATUS IN ('A','E'))
                        AND (N.IDSISTEMA IN ('DFE','EST') OR N.IDSISTEMA IS NULL)
                        AND (N.DTEXPORTACAO IS NULL)
                        AND (N.CDFORNECED = FO.CDFORNECED (+))
                        AND (F.CDFILIAL = N.CDFILIRECE)
                        AND NOT EXISTS (SELECT CDFILIAL
                                          FROM NFRELACPEXOL O
                                         WHERE O.CDFILIAL = N.CDFILIAL
                                           AND O.NRLANCTONF = N.NRLANCTONF))
   LOOP
      V_BASEICMS     := 0;
      V_VALRICMS     := 0;
      V_BASEIPI      := 0;
      V_VALRIPI      := 0;
      V_BASEICMRET   := 0;
      V_VALRICMRET   := 0;
      V_VALRIRRF     := 0;
      V_VALRINSS     := 0;
      V_VALRISS      := 0;
      V_VALRPIS      := 0;
      V_VALRCOFINS   := 0;
      V_VALRCSLL     := 0;
      V_BASEPISST    := 0;
      V_VALRPISST    := 0;
      V_BASECOFINSST := 0;
      V_VALRCOFINSST := 0;

      /* Valores referente a impostos */
      BEGIN
         SELECT VRTOTBCALCNF, VRTOTIMPONF
           INTO V_BASEICMS, V_VALRICMS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_ENTRADA.CDFILIAL
            AND NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND CDIMPOSTO = '00';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_BASEICMS := 0;
            V_VALRICMS := 0;
      END;

      BEGIN
         SELECT VRTOTBCALCNF, VRTOTIMPONF
           INTO V_BASEIPI, V_VALRIPI
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_ENTRADA.CDFILIAL
            AND NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND CDIMPOSTO = '10';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_BASEIPI := 0;
            V_VALRIPI := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRIRRF
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_ENTRADA.CDFILIAL
            AND NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND CDIMPOSTO = '20';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRIRRF := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRINSS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_ENTRADA.CDFILIAL
            AND NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND CDIMPOSTO = '40';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRINSS := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRISS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_ENTRADA.CDFILIAL
            AND NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND CDIMPOSTO = '30';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRISS := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRPIS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_ENTRADA.CDFILIAL
            AND NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND CDIMPOSTO = '50';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRPIS := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRCOFINS
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_ENTRADA.CDFILIAL
            AND NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND CDIMPOSTO = '60';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRCOFINS := 0;
      END;

      BEGIN
         SELECT VRTOTIMPONF
           INTO V_VALRCSLL
           FROM IMPOSNFTOT
          WHERE CDFILIAL = C_ENTRADA.CDFILIAL
            AND NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND CDIMPOSTO = '80';
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_VALRCSLL := 0;
      END;

      /* ICMS Solidrio (Retido) */
      SELECT SUM(VRTOTBCALCNF), SUM(VRTOTIMPONF)
        INTO V_BASEICMRET, V_VALRICMRET
        FROM IMPOSNFTOT IMP, IMPOSTO I
       WHERE IMP.CDFILIAL = C_ENTRADA.CDFILIAL
         AND IMP.NRLANCTONF = C_ENTRADA.NRLANCTONF
         AND IMP.CDIMPOSTO = I.CDIMPOSTO
         AND I.IDTRATIMPO = 'R'
         AND I.IDUTVRMENSBC = 'S';

      /* PIS substituio tributria */
      BEGIN
         SELECT VRTOTBCALCNF, VRTOTIMPONF
           INTO V_BASEPISST, V_VALRPISST
           FROM IMPOSNFTOT IM, IMPOSTO I
          WHERE I.CDIMPOSTO = '50'
            AND IM.CDFILIAL = C_ENTRADA.CDFILIAL
            AND IM.NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND IM.CDIMPOSTO = I.CDIMPOSTRIB;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_BASEPISST := 0;
            V_VALRPISST := 0;
      END;

      /* COFINS substituio tributria */
      BEGIN
         SELECT VRTOTBCALCNF, VRTOTIMPONF
           INTO V_BASECOFINSST, V_VALRCOFINSST
           FROM IMPOSNFTOT IM, IMPOSTO I
          WHERE I.CDIMPOSTO = '60'
            AND IM.CDFILIAL = C_ENTRADA.CDFILIAL
            AND IM.NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND IM.CDIMPOSTO = I.CDIMPOSTRIB;
      EXCEPTION
         WHEN NO_DATA_FOUND THEN
            V_BASECOFINSST := 0;
            V_VALRCOFINSST := 0;
      END;


      UPDATE USR_ZWA
      SET WA_EMPRESA = C_ENTRADA.EMPRESA,
          WA_FILIAL  = C_ENTRADA.FILIAL,
          WA_DOC     = C_ENTRADA.NRNOTAFISC,
          WA_SERIE   = C_ENTRADA.CDSERIEENTR,
          WA_EMISSAO = C_ENTRADA.DTEMISSAO,
          WA_CGCFORN = SUBSTR(C_ENTRADA.NRINSJURFORN,1,14),
          WA_COND    = C_ENTRADA.CDFORMPGTO,
          WA_BASEICM = V_BASEICMS,
          WA_VALICM  = V_VALRICMS,
          WA_BASEIPI = V_BASEIPI,
          WA_VALIPI  = V_VALRIPI,
          WA_VALMERC = C_ENTRADA.VRPRODUTOS,
          WA_VALBRUT = C_ENTRADA.VRNOTAFISC,
          WA_BRICMS  = V_BASEICMRET,
          WA_ICMSRET = V_VALRICMRET,
          WA_IRRF    = V_VALRIRRF,
          WA_INSS    = V_VALRINSS,
          WA_ISS     = V_VALRISS,
          WA_ICMS    = 0,
          WA_VALPIS  = V_VALRPIS,
          WA_VALCOFI = V_VALRCOFINS,
          WA_VALCSLL = V_VALRCSLL,
          WA_BASEPS3 = V_BASEPISST,
          WA_VALPS3  = V_VALRPISST,
          WA_BASECF3 = V_BASECOFINSST,
          WA_VALCF3  = V_VALRCOFINSST,
          WA_NFELETR = NULL,
          WA_TPEDI   = '2',
          WA_DTGRV   = V_DTGRV,
          WA_HRGRV   = V_HRGRV
      WHERE WA_CDFILIAL = C_ENTRADA.CDFILIAL
        AND WA_NRLANCTONF = C_ENTRADA.NRLANCTONF;

      IF SQL%ROWCOUNT = 0 THEN
         /* Insere corpo de nota fiscal */
         INSERT INTO USR_ZWA
            (WA_CDFILIAL, WA_NRLANCTONF, WA_EMPRESA, WA_FILIAL, WA_DOC, WA_SERIE, WA_EMISSAO, WA_CGCFORN,
             WA_COND, WA_BASEICM, WA_VALICM, WA_BASEIPI, WA_VALIPI, WA_VALMERC, WA_VALBRUT, WA_BRICMS, WA_ICMSRET, WA_IRRF,
             WA_INSS, WA_ISS, WA_ICMS, WA_VALPIS, WA_VALCOFI, WA_VALCSLL, WA_BASEPS3,
             WA_VALPS3, WA_BASECF3, WA_VALCF3, WA_NFELETR, WA_TPEDI, WA_DTGRV, WA_HRGRV)
         VALUES
            (C_ENTRADA.CDFILIAL, C_ENTRADA.NRLANCTONF, C_ENTRADA.EMPRESA, C_ENTRADA.FILIAL, C_ENTRADA.NRNOTAFISC, C_ENTRADA.CDSERIEENTR, C_ENTRADA.DTEMISSAO, SUBSTR(C_ENTRADA.NRINSJURFORN,1,2),
             C_ENTRADA.CDFORMPGTO, V_BASEICMS, V_VALRICMS, V_BASEIPI, V_VALRIPI, C_ENTRADA.VRPRODUTOS, C_ENTRADA.VRNOTAFISC, V_BASEICMRET, V_VALRICMRET, V_VALRIRRF,
             V_VALRINSS, V_VALRISS, 0, V_VALRPIS, V_VALRCOFINS, V_VALRCSLL, V_BASEPISST,
             V_VALRPISST, V_BASECOFINSST, V_VALRCOFINSST, NULL, '1', V_DTGRV, V_HRGRV);
      END IF;

      /* Verificao dos itens da nota fiscal */
      FOR C_ITEMENTRADA IN (SELECT I.NRSEQITPROD, P.CDPRODINTE, I.QTITEMPROD, I.VRUNITITEM, I.CDFISOPEITEM,
                                   I.VRTOTAITEM
                              FROM ITEMPRODUTO I, PRODUTO P
                             WHERE I.CDFILIAL = C_ENTRADA.CDFILIAL
                               AND I.NRLANCTONF = C_ENTRADA.NRLANCTONF
                               AND I.CDPRODUTO = P.CDPRODUTO
                           )
      LOOP
         V_VALRICMSIT   := 0;
         V_ALIQICMSIT   := 0;
         V_BASEICMSIT   := 0;
         V_VALRIPIIT    := 0;
         V_ALIQIPIIT    := 0;
         V_BASEIPIIT    := 0;
         V_VALRIRRFIT   := 0;
         V_ALIQIRRFIT   := 0;
         V_BASEIRRFIT   := 0;
         V_VALRISSIT    := 0;
         V_ALIQISSIT    := 0;
         V_BASEISSIT    := 0;
         V_VALRINSSIT   := 0;
         V_ALIQINSSIT   := 0;
         V_BASEINSSIT   := 0;
         V_BASEICMRETIT := 0;
         V_VALRICMRETIT := 0;
         V_BASEPISSTIT  := 0;
         V_VALRPISSTIT  := 0;
         V_ALIQPISSTIT  := 0;
         V_BASECOFSTIT  := 0;
         V_VALRCOFSTIT  := 0;
         V_ALIQCOFSTIT  := 0;

         /* Valores referente a impostos */
         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRICMSIT, V_ALIQICMSIT, V_BASEICMSIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_ENTRADA.CDFILIAL
               AND NRLANCTONF = C_ENTRADA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMENTRADA.NRSEQITPROD
               AND CDIMPOSTO = '00'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRICMSIT := 0;
               V_ALIQICMSIT := 0;
               V_BASEICMSIT := 0;
         END;

         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRIPIIT, V_ALIQIPIIT, V_BASEIPIIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_ENTRADA.CDFILIAL
               AND NRLANCTONF = C_ENTRADA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMENTRADA.NRSEQITPROD
               AND CDIMPOSTO = '10'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRIPIIT := 0;
               V_ALIQIPIIT := 0;
               V_BASEIPIIT := 0;
         END;

         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRIRRFIT, V_ALIQIRRFIT, V_BASEIRRFIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_ENTRADA.CDFILIAL
               AND NRLANCTONF = C_ENTRADA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMENTRADA.NRSEQITPROD
               AND CDIMPOSTO = '20'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRIRRFIT := 0;
               V_ALIQIRRFIT := 0;
               V_BASEIRRFIT := 0;
         END;

         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRISSIT, V_ALIQISSIT, V_BASEISSIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_ENTRADA.CDFILIAL
               AND NRLANCTONF = C_ENTRADA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMENTRADA.NRSEQITPROD
               AND CDIMPOSTO = '30'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRISSIT := 0;
               V_ALIQISSIT := 0;
               V_BASEISSIT := 0;
         END;

         BEGIN
            SELECT VRIMPOSTOIT, VRALIQITEM, VRBASECALCIT
              INTO V_VALRINSSIT, V_ALIQINSSIT, V_BASEINSSIT
              FROM ITEMPROIMPOS
             WHERE CDFILIAL = C_ENTRADA.CDFILIAL
               AND NRLANCTONF = C_ENTRADA.NRLANCTONF
               AND NRSEQITPROD = C_ITEMENTRADA.NRSEQITPROD
               AND CDIMPOSTO = '40'
               AND NRITPROIMPOS = '1';
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_VALRINSSIT := 0;
               V_ALIQINSSIT := 0;
               V_BASEINSSIT := 0;
         END;

         /* ICMS Solidrio (Retido) */
         SELECT SUM(VRBASECALCIT), SUM(VRIMPOSTOIT)
           INTO V_BASEICMRETIT, V_VALRICMRETIT
           FROM ITEMPROIMPOS IMP, IMPOSTO I
          WHERE IMP.CDFILIAL = C_ENTRADA.CDFILIAL
            AND IMP.NRLANCTONF = C_ENTRADA.NRLANCTONF
            AND IMP.NRITPROIMPOS = '1'
            AND IMP.CDIMPOSTO = I.CDIMPOSTO
            AND I.IDTRATIMPO = 'R'
            AND I.IDUTVRMENSBC = 'S';

         /* PIS substituio tributria */
         BEGIN
            SELECT VRBASECALCIT, VRIMPOSTOIT, VRALIQITEM
              INTO V_BASEPISSTIT, V_VALRPISSTIT, V_ALIQPISSTIT
              FROM ITEMPROIMPOS IM, IMPOSTO I
             WHERE I.CDIMPOSTO = '50'
               AND IM.CDFILIAL = C_ENTRADA.CDFILIAL
               AND IM.NRLANCTONF = C_ENTRADA.NRLANCTONF
               AND IM.NRITPROIMPOS = '1'
               AND IM.CDIMPOSTO = I.CDIMPOSTRIB;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_BASEPISSTIT := 0;
               V_VALRPISSTIT := 0;
               V_ALIQPISSTIT := 0;
         END;

         /* COFINS substituio tributria */
         BEGIN
            SELECT VRBASECALCIT, VRIMPOSTOIT, VRALIQITEM
              INTO V_BASECOFSTIT, V_VALRCOFSTIT, V_ALIQCOFSTIT
              FROM ITEMPROIMPOS IM, IMPOSTO I
             WHERE I.CDIMPOSTO = '60'
               AND IM.CDFILIAL = C_ENTRADA.CDFILIAL
               AND IM.NRLANCTONF = C_ENTRADA.NRLANCTONF
               AND IM.NRITPROIMPOS = '1'
               AND IM.CDIMPOSTO = I.CDIMPOSTRIB;
         EXCEPTION
            WHEN NO_DATA_FOUND THEN
               V_BASECOFSTIT := 0;
               V_VALRCOFSTIT := 0;
               V_ALIQCOFSTIT := 0;
         END;


         UPDATE USR_ZWB
         SET WB_EMPRESA = C_ENTRADA.EMPRESA,
             WB_FILIAL  = C_ENTRADA.FILIAL,
             WB_DOC     = C_ENTRADA.NRNOTAFISC,
             WB_SERIE   = C_ENTRADA.CDSERIEENTR,
             WB_CGCFORN = SUBSTR(C_ENTRADA.NRINSJURFORN,1,14),
             WB_LOJA    = C_ENTRADA.LOJA,
             WB_COD     = SUBSTR(C_ITEMENTRADA.CDPRODINTE,1,15),
             WB_QUANT   = C_ITEMENTRADA.QTITEMPROD,
             WB_VUNIT   = C_ITEMENTRADA.VRUNITITEM,
             WB_TOTAL   = C_ITEMENTRADA.VRTOTAITEM,
             WB_CCUSTO  = C_ENTRADA.CDFILIRECE,
             WB_TES     = SUBSTR(C_ENTRADA.CDTIPOOPER,1,3),
             WB_CF      = SUBSTR(C_ITEMENTRADA.CDFISOPEITEM,1,5),
             WB_VALICM  = V_VALRICMSIT,
             WB_VALIPI  = V_VALRIPIIT,
             WB_IPI     = V_ALIQIPIIT,
             WB_PICM    = V_ALIQICMSIT,
             WB_BASEICM = V_BASEICMSIT,
             WB_BASEIPI = V_BASEIPIIT,
             WB_ICMSRET = V_VALRICMRETIT,
             WB_BRICMS  = V_BASEICMRETIT,
             WB_ICMSCOM = 0,
             WB_BASEIRR = V_BASEIRRFIT,
             WB_ALIQIRR = V_ALIQIRRFIT,
             WB_VALIRR  = V_VALRIRRFIT,
             WB_BASEISS = V_BASEISSIT,
             WB_ALIQISS = V_ALIQISSIT,
             WB_VALISS  = V_VALRISSIT,
             WB_BASEINS = V_BASEINSSIT,
             WB_ALIQINS = V_ALIQINSSIT,
             WB_VALINS  = V_VALRINSSIT,
             WB_ALIQCF3 = V_ALIQCOFSTIT,
             WB_VALCF3  = V_VALRCOFSTIT,
             WB_VALPS3  = V_VALRPISSTIT,
             WB_BASECF3 = V_BASECOFSTIT,
             WB_BASEPS3 = V_BASEPISSTIT,
             WB_ALIQPS3 = V_ALIQPISSTIT,
             WB_VALIMP5 = 0,
             WB_VALIMP6 = 0,
             WB_TPEDI   = '2',
             WB_DTGRV   = V_DTGRV,
             WB_HRGRV   = V_HRGRV
         WHERE WB_CDFILIAL = C_ENTRADA.CDFILIAL
           AND WB_NRLANCTONF = C_ENTRADA.NRLANCTONF
           AND WB_ITEM = C_ITEMENTRADA.NRSEQITPROD;

         IF SQL%ROWCOUNT = 0 THEN
            /* Insere itens da nota fiscal */
            INSERT INTO USR_ZWB
               (WB_CDFILIAL, WB_NRLANCTONF, WB_EMPRESA, WB_FILIAL, WB_DOC, WB_SERIE, WB_CGCFORN, WB_LOJA,
                WB_ITEM, WB_COD, WB_QUANT, WB_VUNIT, WB_TOTAL, WB_CCUSTO, WB_TES, WB_CF, WB_VALICM,
                WB_VALIPI, WB_IPI, WB_PICM, WB_BASEICM, WB_BASEIPI, WB_ICMSRET, WB_BRICMS, WB_ICMSCOM,
                WB_BASEIRR, WB_ALIQIRR, WB_VALIRR, WB_BASEISS, WB_ALIQISS, WB_VALISS, WB_BASEINS,
                WB_ALIQINS, WB_VALINS, WB_ALIQCF3, WB_VALCF3, WB_VALPS3, WB_BASECF3, WB_BASEPS3,
                WB_ALIQPS3, WB_VALIMP5, WB_VALIMP6, WB_TPEDI, WB_DTGRV, WB_HRGRV)
            VALUES
               (C_ENTRADA.CDFILIAL, C_ENTRADA.NRLANCTONF, C_ENTRADA.EMPRESA, C_ENTRADA.FILIAL, C_ENTRADA.NRNOTAFISC, C_ENTRADA.CDSERIEENTR, SUBSTR(C_ENTRADA.NRINSJURFORN,1,14), C_ENTRADA.LOJA,
                C_ITEMENTRADA.NRSEQITPROD, SUBSTR(C_ITEMENTRADA.CDPRODINTE,1,15), C_ITEMENTRADA.QTITEMPROD, C_ITEMENTRADA.VRUNITITEM,
                C_ITEMENTRADA.VRTOTAITEM, C_ENTRADA.CDFILIRECE, SUBSTR(C_ENTRADA.CDTIPOOPER,1,3), SUBSTR(C_ITEMENTRADA.CDFISOPEITEM,1,5), V_VALRICMSIT,
                V_VALRIPIIT, V_ALIQIPIIT, V_ALIQICMSIT, V_BASEICMSIT, V_BASEIPIIT, V_VALRICMRETIT, V_BASEICMRETIT, 0,
                V_BASEIRRFIT, V_ALIQIRRFIT, V_VALRIRRFIT, V_BASEISSIT, V_ALIQISSIT, V_VALRISSIT,
                V_BASEINSSIT, V_ALIQINSSIT, V_VALRINSSIT,
                V_ALIQCOFSTIT, V_VALRCOFSTIT, V_VALRPISSTIT, V_BASECOFSTIT, V_BASEPISSTIT,
                V_ALIQPISSTIT, 0, 0, '1', V_DTGRV, V_HRGRV);
         END IF;
      END LOOP;


      /* Verificao rateios contbeis por produto */
      FOR C_RATEPROD IN (SELECT R.NRSEQITPROD, SUBSTR(F.CDGRUPFILI,9,2) AS ITEM,
                                R.CDCENTCUSNF, T.VRRATETOT, SUM(VRRATENF) AS VRRATENF
                           FROM RATEIONF R,
                               (SELECT CDFILIAL, MIN(CDGRUPFILI) AS CDGRUPFILI
                                  FROM FILGRUPFILI
                                 GROUP BY CDFILIAL) F,
                               (SELECT NRSEQITPROD, SUM(VRRATENF) AS VRRATETOT
                                  FROM RATEIONF
                                 WHERE CDFILIAL = C_ENTRADA.CDFILIAL
                                   AND NRLANCTONF = C_ENTRADA.NRLANCTONF
                                 GROUP BY NRSEQITPROD) T
                          WHERE R.CDFILIAL = C_ENTRADA.CDFILIAL
                            AND R.NRLANCTONF = C_ENTRADA.NRLANCTONF
                            AND R.CDFILICCUST = F.CDFILIAL
                            AND R.NRSEQITPROD = T.NRSEQITPROD
                          GROUP BY R.NRSEQITPROD, SUBSTR(F.CDGRUPFILI,9,2), R.CDCENTCUSNF, T.VRRATETOT
                        )
      LOOP

         UPDATE USR_RATEIO_CONTABIL
         SET DE_ITEM       = C_RATEPROD.ITEM,
             DE_EMPRESA    = C_ENTRADA.EMPRESA,
             DE_FILIAL     = C_ENTRADA.FILIAL,
             DE_DOC        = C_ENTRADA.NRNOTAFISC,
             DE_SERIE      = C_ENTRADA.CDSERIEENTR,
             DE_CGCFORN    = SUBSTR(C_ENTRADA.NRINSJURFORN,1,14),
             DE_PERC       = ROUND(((100 * C_RATEPROD.VRRATENF) / C_RATEPROD.VRRATETOT),2),
             DE_CC         = C_RATEPROD.CDCENTCUSNF,
             DE_CUSTO1     = C_RATEPROD.VRRATENF,
             DE_CUSTO2     = 0,
             DE_CUSTO3     = 0,
             DE_CUSTO4     = 0,
             DE_CUSTO5     = 0,
             DE_DTGRV      = V_DTGRV,
             DE_HRGRV      = V_HRGRV
         WHERE DE_CDFILIAL = C_ENTRADA.CDFILIAL
           AND DE_NRLANCTONF = C_ENTRADA.NRLANCTONF
           AND DE_ITEMNF = C_RATEPROD.NRSEQITPROD
           AND DE_ITEM = C_RATEPROD.ITEM
           AND DE_CC = C_RATEPROD.CDCENTCUSNF;

         IF SQL%ROWCOUNT = 0 THEN
            /* Insere rateio contbil de produtos */
            INSERT INTO USR_RATEIO_CONTABIL
               (DE_CDFILIAL, DE_NRLANCTONF, DE_ITEMNF, DE_ITEM, DE_EMPRESA, DE_FILIAL, DE_DOC,
                DE_SERIE, DE_CGCFORN, DE_PERC, DE_CC, DE_CUSTO1, DE_CUSTO2, DE_CUSTO3,
                DE_CUSTO4, DE_CUSTO5, DE_DTGRV, DE_HRGRV)
            VALUES
               (C_ENTRADA.CDFILIAL, C_ENTRADA.NRLANCTONF, C_RATEPROD.NRSEQITPROD, C_RATEPROD.ITEM,
                C_ENTRADA.EMPRESA, C_ENTRADA.FILIAL, C_ENTRADA.NRNOTAFISC,
                C_ENTRADA.CDSERIEENTR, SUBSTR(C_ENTRADA.NRINSJURFORN,1,14), ((100 * C_RATEPROD.VRRATENF) / C_RATEPROD.VRRATETOT), C_RATEPROD.CDCENTCUSNF,
                C_RATEPROD.VRRATENF, 0, 0, 0, 0, V_DTGRV, V_HRGRV);
         END IF;
      END LOOP;

      /* Inclui a data de exportao para os documentos exportados*/
      UPDATE NOTAFISCAL
      SET DTEXPORTACAO = V_DTGRV
      WHERE CDFILIAL   = C_ENTRADA.CDFILIAL    AND
            NRLANCTONF = C_ENTRADA.NRLANCTONF;
   END LOOP;
   COMMIT;
END;
/
